//
//  DrawPath
//
//  Created by Shawn on 2007-10-18.
//  Copyright (c) 2007 Harvard University. All rights reserved.
//

/*
DrawPath handles the high-level organization and drawing of paths.
Path data is accessed by looping through the doubly-linked lists in the 
Path object.  Path is a list 

a 
*/
package edu.harvard.med.nano
{
    import de.polygonal.ds.*;
    import edu.harvard.med.nano.Path;
    import edu.harvard.med.nano.PathSegment;
    import flash.display.*;
    import flash.events.*;
    import flash.text.*;
    
    public class DrawPath extends Sprite {
        
        private var path:Path;
        public var currentSlice:int = 0;
        public var pathScale = 1;
        
        function DrawPath(path:Path) {
            // set up
            //trace(this.x, this.y, this.parent);
            this.x = 160;
            this.path = path;
            path.drawPath = this;
            this.addEventListener(MouseEvent.MOUSE_DOWN, pathDrag);
            this.addEventListener(MouseEvent.MOUSE_UP, pathReleased);
        }
        
        public function addDrawSeg(ds:DrawSegment):void {
            this.addChild(ds);
        }
        
        private function pathDrag(event:MouseEvent):void {
            this.startDrag();
        }
        
        private function pathReleased(event:MouseEvent):void {
            this.stopDrag();
        }
        
        // update with new data and redraw
        public function update():void {
            if (this.path.pathList.size == 0) {
                return;
            }
            
            // look at the first helix and check how many segments it has
            var segCount:int = this.path.pathList.head.data.size;
            var width:int = segCount * 42 * pathScale; // 
            var height:int = 20 * pathScale; // * scale
            var yspacing:int = 10 * pathScale; // * scale
            var ypos:int = 10;
            var xpos:int; // = -segCount*42;
            
            var iter:DListIterator = this.path.pathList.getListIterator();
            // loop through Paths
            graphics.clear();
            for (iter.start(); iter.valid(); iter.forth()) {
                var helixNum:int;
                //helixNum = segList.head.data.helixNum;
                
                graphics.beginFill(0xffffff,0);
                graphics.lineStyle(1, 0x0066cc, 1, true);
                graphics.endFill();
                
                // draw the slice line for each segment, highlight if current
                var segIter:DListIterator;
                segIter = iter.node.data.getListIterator();
                
                for (segIter.start(); segIter.valid(); segIter.forth()) {
                    
                    // draw a vertical line to represent each segment boundary
                    graphics.beginFill(0xffffff,0);
                    if (currentSlice == segIter.node.data.segIndex) {
                        // highlight the current slice
                        graphics.lineStyle(1, 0xcc0000, 1, true);
                    } else {
                        graphics.lineStyle(1, 0x0066cc, 1, true);
                    }
                    xpos = segIter.node.data.segIndex * 42 * pathScale;
                    graphics.moveTo(xpos-pathScale, ypos-2);
                    graphics.lineTo(xpos-pathScale, ypos+height+2);
                    graphics.endFill();
                    
                    segIter.node.data.drawSegment.x = xpos;
                    segIter.node.data.drawSegment.y = ypos;
                    
                }
                graphics.endFill();
                for (segIter.start(); segIter.valid(); segIter.forth()) {
                    segIter.node.data.drawSegment.refreshSegment(pathScale);
                }
                ypos = ypos + height + yspacing;
                
            }
        }
    }
}