//
//  DrawSegment
//
//  Created by Shawn on 2007-11-11.
//

/*
DrawSegment handles the segment-level drawing of 
the scaffold and staple paths.

One DrawSegment is used for each 21-base stretch of the DNA structure.
An instance of DrawPath is used to create and refresh DrawSegments.
*/

package edu.harvard.med.nano
{
    import flash.display.*;
    import flash.events.*;
    import flash.text.*;
    import edu.harvard.med.nano.PathSegment;
    
    class DrawSegment extends Sprite {
        public static var COLOR_SCAF:uint = 0x999999;
        public static var COLOR_STAP:uint = 0x990000;
        public static var COLOR_GRID:uint = 0xeeeeee;
        public static var COLOR_7:uint = 0xcccccc;
        
        // Pointer to data
        public var pathSegment:PathSegment;
        
        // DrawSegment-specific variables
        public var scale:int;
        private var drawHeight:int;
/*        public var tf:TextField;
        public var tfm:TextFormat;
*/        
        function DrawSegment(x:int=0, y:int=0, scale:int=1) {
            // Minimal setup; everything else is added on first refreshNode()
            this.x = x;
            this.y = y;
            this.scale = scale;
            /*
            this.tf = new TextField();
            this.tfm = tf.getTextFormat();
            tf.antiAliasType = "advanced";
            tf.autoSize = "left";
            tf.selectable = false;
            tf.mouseEnabled = false;
            this.addChild(tf);*/
        }
        
        public function refreshSegment(scale:int=1) {
            this.scale = scale;
            this.refreshPositions();
            this.refreshXovers();
        }
        
        private function refreshPositions() {
            var i:int;
            this.drawHeight = 20*this.scale;
            graphics.clear();
            
            // draw a tick mark to represent each base position
            for (i = 0; i < 21; i++) {
                graphics.beginFill(0xffcc99, 1);
                if (i % 7 == 0) {
                    graphics.lineStyle(scale, COLOR_7);
                } else {
                    graphics.lineStyle(scale, COLOR_GRID);
                }
                graphics.moveTo(i*2*scale, drawHeight/2-scale);
                graphics.lineTo(i*2*scale, drawHeight/2+scale);
                graphics.endFill();
            }
        }
        
        private function refreshXovers() {
            var i:int;
            var yxoverOffset:int = drawHeight;
            var xoverColor:uint;
            
            for (i = 0; i < 21; i++) {
                if (this.pathSegment.scafxover[i] != -1) {
                    if (this.pathSegment.helixNum % 2 == 1) {
                        yxoverOffset = drawHeight;
                        xoverColor = 0x00cc00;
                    } else {
                        yxoverOffset = drawHeight;
                        xoverColor = 0x00cccc; // even is messed up
                    }
                    
                    if (i == 4 || i == 15) { // p0
                        trace(this.pathSegment.helixNum, ":" , this.x, this.y, this.pathSegment.segIndex);
                        trace(this.pathSegment.p0.helixNum, ":" ,  this.pathSegment.p0.drawSegment.x, this.pathSegment.p0.drawSegment.y, this.pathSegment.p0.segIndex);
                        graphics.beginFill(0xffffff, 1);
                        graphics.lineStyle(scale, xoverColor);
                        graphics.moveTo(i*2*scale, 0);
                        graphics.lineTo(i*2*scale, this.pathSegment.p0.drawSegment.y);
                        graphics.endFill();
                    } else if (i == 8 || i == 18) { // p1
                        graphics.beginFill(0xffffff, 1);
                        graphics.lineStyle(scale, xoverColor);
                        graphics.moveTo(i*2*scale, 0);
                        graphics.lineTo(i*2*scale, this.pathSegment.p1.drawSegment.y);
                        graphics.endFill();
                    } else if (i == 1 || i == 11) { // p2
                        graphics.beginFill(0xffffff, 1);
                        graphics.lineStyle(scale, xoverColor);
                        graphics.moveTo(i*2*scale, 0);
                        graphics.lineTo(i*2*scale, this.pathSegment.p2.drawSegment.y);
                        graphics.endFill();
                    }
                }
            }
        }
    }
}